"""
Basic GuiStructure with minimal functionalities
"""

from __future__ import annotations

from .aim import Aim
from .button_box import ButtonBox
from .category import Category
from .figure_option import FigureOption
from .filename_box import FileNameBox
from .flexible_amount_option import FlexibleAmount
from .float_box import FloatBox
from .function_button import FunctionButton
from .hint import Hint
from .int_box import IntBox
from .list_box import ListBox
from .option import Option
from .page import Page
from .result_figure import ResultFigure
from .result_text import ResultText
from .text_box import TextBox
from .result_export import ResultExport

__all__ = [
    "Aim",
    "ButtonBox",
    "Category",
    "FigureOption",
    "FileNameBox",
    "FloatBox",
    "FunctionButton",
    "Hint",
    "IntBox",
    "ListBox",
    "Option",
    "Page",
    "ResultFigure",
    "ResultText",
    "ResultExport",
    "TextBox",
    "FlexibleAmount",
]
